@@ -837,10 +837,12 @@ build_dbfield_tip (CanvasTip * tip)
 	double x1, y1, x2, y2;
 
 	field =  DB_FIELD (tip->tip_obj);
-	if (field->default_val)
+	if (field->default_value) {
+		gchar *tmpstr = gda_value_stringify (field->default_value);
 		str = g_strdup_printf (_("Field type: %s\n"
-				       "Def. value: %s"), field->type->sqlname,
-				       field->default_val);
+					 "Def. value: %s"), field->type->sqlname, tmpstr);
+		g_free (tmpstr);
+	}
 	else
 		str = g_strdup_printf (_("Field type: %s"), field->type->sqlname);
 
