@@ -113,8 +113,24 @@ main_page_query_init (MainPageQuery * wid)
 {
 	GtkWidget *sw, *bb;
 
-	/* setting spaces,... */
-	gtk_container_set_border_width (GTK_CONTAINER (wid), GNOME_PAD / 2);
+	/* Toolbar */
+	bb = gnome_db_new_toolbar_widget (GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
+	gtk_box_pack_start (GTK_BOX (wid), bb, FALSE, TRUE, GNOME_PAD / 2);
+	gtk_widget_show (bb);
+	wid->queries_bbox = bb;
+
+	wid->new_query = gtk_toolbar_insert_stock (GTK_TOOLBAR (bb), GTK_STOCK_NEW,
+						   _("Create a new query"), NULL,
+						   GTK_SIGNAL_FUNC (create_query_button_cb), wid, -1);
+	wid->edit_query = gtk_toolbar_insert_stock (GTK_TOOLBAR (bb), GTK_STOCK_PROPERTIES,
+						    _("Display selected query properties"), NULL,
+						    GTK_SIGNAL_FUNC (edit_query_button_cb), wid, 1);
+	wid->exec_query = gtk_toolbar_insert_stock (GTK_TOOLBAR (bb), GTK_STOCK_EXECUTE,
+						    _("Execute selected query"), NULL,
+						    GTK_SIGNAL_FUNC (exec_query_button_cb), wid, -1);
+	wid->remove_query = gtk_toolbar_insert_stock (GTK_TOOLBAR (bb), GTK_STOCK_DELETE,
+						      _("Delete selected query"), NULL,
+						      GTK_SIGNAL_FUNC (drop_query_button_cb), wid, -1);
 
 	/* Scrolled Window for CTree */
 	sw = gtk_scrolled_window_new (NULL, NULL);
@@ -147,45 +163,6 @@ main_page_query_init (MainPageQuery * wid)
 			    "button_press_event",
 			    G_CALLBACK (press_handler_event), wid);
 
-	/*
-	 * buttons for the queries
-	 */
-
-	/* Button Box */
-	bb = gtk_hbutton_box_new ();
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (bb), GTK_BUTTONBOX_SPREAD);
-	gtk_box_pack_end (GTK_BOX (wid), bb, FALSE, TRUE, GNOME_PAD);
-	gtk_widget_show (bb);
-	wid->queries_bbox = bb;
-
-	/* New Query Button */
-	wid->new_query = gtk_button_new_with_label (_("Create Query"));
-	gtk_container_add (GTK_CONTAINER (bb), wid->new_query);
-	gtk_widget_show (wid->new_query);
-	g_signal_connect (G_OBJECT (wid->new_query), "clicked",
-			    G_CALLBACK (create_query_button_cb), wid);
-
-	/* Edit Query Button */
-	wid->edit_query = gtk_button_new_with_label (_("Properties"));
-	gtk_container_add (GTK_CONTAINER (bb), wid->edit_query);
-	gtk_widget_show (wid->edit_query);
-	g_signal_connect (G_OBJECT (wid->edit_query), "clicked",
-			    G_CALLBACK (edit_query_button_cb), wid);
-
-	/* View Query Button */
-	wid->exec_query = gtk_button_new_with_label (_("Execute"));
-	gtk_container_add (GTK_CONTAINER (bb), wid->exec_query);
-	g_signal_connect (G_OBJECT (wid->exec_query), "clicked",
-			    G_CALLBACK (exec_query_button_cb), wid);
-	gtk_widget_show (wid->exec_query);
-
-	/* Remove Query Button */
-	wid->remove_query = gtk_button_new_with_label (_("Delete"));
-	gtk_container_add (GTK_CONTAINER (bb), wid->remove_query);
-	gtk_widget_show (wid->remove_query);
-	g_signal_connect (G_OBJECT (wid->remove_query), "clicked",
-			    G_CALLBACK (drop_query_button_cb), wid);
-
 	wid->sel_node = NULL;
 	wid->new_dlgs = NULL;
 }
@@ -424,8 +401,8 @@ edit_query_button_cb (GtkWidget * button, MainPageQuery * mpq)
 							   GTK_STOCK_CLOSE, GTK_RESPONSE_DELETE_EVENT, NULL);
 			query_edit_dlg_name_changed_cb (rd->query, GTK_DIALOG (dlg));
 			editor = query_editor_new (rd->query);
-			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), editor, TRUE,
-					    TRUE, 0);
+			gtk_widget_set_size_request (GTK_WIDGET (editor), 750, 550);
+			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), editor, TRUE, TRUE, 0);
 			g_object_set_data (G_OBJECT (dlg), "query", rd->query);
 
 			/* CBs for the dialog */
@@ -492,7 +469,6 @@ exec_query_button_cb (GtkWidget * button, MainPageQuery * mpq)
 		QueryEnv *env;
 		QueryExec *qx;
 		GtkWidget *dlg;
-		QueryExecStatus status;
 
 		rd = (Row_Data *)
 			gtk_ctree_node_get_row_data (GTK_CTREE (mpq->ctree), mpq->sel_node);
@@ -520,10 +496,11 @@ create_query_button_cb (GtkWidget * button, MainPageQuery * mpq)
 
 
 	dlg = gtk_dialog_new_with_buttons (_("Creation of a new query"), NULL, 0, NULL);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
+	gtk_widget_set_size_request (GTK_WIDGET (dlg), 600, 400);
 	wid = query_create_druid_new (mpq->conf);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
-			    wid, TRUE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), wid, TRUE, TRUE, GNOME_PAD);
 	gtk_widget_show (wid);
 	g_object_set_data (G_OBJECT (dlg), "druid", wid);
 	g_object_set_data (G_OBJECT (dlg), "mpq", mpq);
