@@ -1028,7 +1028,9 @@ query_editor_expr_init (QueryEditorExpr * qee)
 	qee->current_area = NULL;
 	qee->area_container = NULL;
 	qee->name_entry = NULL;
-	qee->alias_entry = NULL;
+	qee->printed_cb = NULL;
+	qee->print_name_label = NULL;
+	qee->print_name_entry = NULL;
 	qee->type_omenu = NULL;
 }
 
@@ -1171,12 +1173,13 @@ expr_query_field_dropped_cb (Query *q, QueryField *old_field, QueryEditorExpr *q
 static void dump_fields (GtkWidget *button, QueryEditorExpr * qee);
 #endif
 static void expr_name_changed_cb (GtkEntry *entry, QueryEditorExpr * qee); 
+static void print_toggled_cb (GtkToggleButton *togglebutton, QueryEditorExpr * qee);
 static void expr_alias_changed_cb (GtkEntry *entry, QueryEditorExpr * qee); 
 static void qee_refresh (QueryEditorExpr * qee);
 static void
 query_editor_expr_initialize (QueryEditorExpr * qee)
 {
-	GtkWidget *vb, *hb, *label, *frame, *table, *entry;
+	GtkWidget *vb, *hb, *label, *frame, *table, *entry, *cb;
 	GtkWidget *menu, *optionmenu;
 
 #ifdef debug
@@ -1209,15 +1212,16 @@ query_editor_expr_initialize (QueryEditorExpr * qee)
 	vb = gtk_vbox_new (FALSE, GNOME_PAD/2.);
 	gtk_container_add (GTK_CONTAINER (frame), vb);
 
-	table = gtk_table_new (3, 2, FALSE);
+	table = gtk_table_new (4, 2, FALSE);
 	
 	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD/2.);
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD/2.);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD/2.);
 	gtk_box_pack_start (GTK_BOX (vb), table, FALSE, TRUE, 0);
 	label = gtk_label_new (_("Type:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-			  0, 0, 0, 0);
+			  GTK_FILL, 0, 0, 0);
 
 	optionmenu = gtk_option_menu_new ();
 	qee->type_omenu = optionmenu;
@@ -1227,8 +1231,9 @@ query_editor_expr_initialize (QueryEditorExpr * qee)
 	gtk_table_attach_defaults (GTK_TABLE (table), optionmenu, 1, 2, 0, 1);
 
 	label = gtk_label_new (_("Name:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-			  0, 0, 0, 0);
+			  GTK_FILL, 0, 0, 0);
 
 	entry = gtk_entry_new ();
 	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2,
@@ -1237,14 +1242,29 @@ query_editor_expr_initialize (QueryEditorExpr * qee)
 	g_signal_connect (G_OBJECT (entry), "changed",
 			    G_CALLBACK (expr_name_changed_cb), qee);
 
-	label = gtk_label_new (_("Print name:"));
+	label = gtk_label_new (_("Printed:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-			  0, 0, 0, 0);
+			  GTK_FILL, 0, 0, 0);
+
+	cb = gtk_check_button_new ();
+	gtk_table_attach (GTK_TABLE (table), cb, 1, 2, 2, 3,
+			  GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
+	qee->printed_cb = cb;
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cb), TRUE);
+	g_signal_connect (G_OBJECT (cb), "toggled",
+			  G_CALLBACK (print_toggled_cb), qee);
+
+	label = gtk_label_new (_("Print name:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
+			  GTK_FILL, 0, 0, 0);
+	qee->print_name_label = label;
 
 	entry = gtk_entry_new ();
-	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 2, 3,
+	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 3, 4,
 			  GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
-	qee->alias_entry = entry;
+	qee->print_name_entry = entry;
 	g_signal_connect (G_OBJECT (entry), "changed",
 			    G_CALLBACK (expr_alias_changed_cb), qee);
 
@@ -1278,6 +1298,12 @@ expr_alias_changed_cb (GtkEntry *entry, QueryEditorExpr * qee)
 		query_field_set_alias (qee->sel_qf, gtk_entry_get_text (entry));
 }
 
+static void 
+print_toggled_cb (GtkToggleButton *togglebutton, QueryEditorExpr * qee)
+{
+	gtk_widget_set_sensitive (qee->print_name_label, gtk_toggle_button_get_active (togglebutton));
+	gtk_widget_set_sensitive (qee->print_name_entry, gtk_toggle_button_get_active (togglebutton));
+}
 
 static void qee_refresh_sel_area (QueryEditorExpr * qee);
 static void expr_type_act_cb (GtkMenuItem *mitem, QueryEditorExpr *qee);
@@ -1386,25 +1412,26 @@ qee_refresh (QueryEditorExpr * qee)
 	/* fill in the entries: name, alias */
 	g_signal_handlers_block_by_func (G_OBJECT (qee->name_entry),
 					 G_CALLBACK (expr_name_changed_cb), qee);
-	g_signal_handlers_block_by_func (G_OBJECT (qee->alias_entry),
+	g_signal_handlers_block_by_func (G_OBJECT (qee->print_name_entry),
 					 G_CALLBACK (expr_alias_changed_cb), qee);
 	if (qee->sel_qf) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (qee->printed_cb), qee->sel_qf->is_printed);
 		if (qee->sel_qf->name)
 			gtk_entry_set_text (GTK_ENTRY (qee->name_entry), qee->sel_qf->name);
 		else
 			gtk_entry_set_text (GTK_ENTRY (qee->name_entry), "");
 		if (qee->sel_qf->alias)
-			gtk_entry_set_text (GTK_ENTRY (qee->alias_entry), qee->sel_qf->alias);
+			gtk_entry_set_text (GTK_ENTRY (qee->print_name_entry), qee->sel_qf->alias);
 		else
-			gtk_entry_set_text (GTK_ENTRY (qee->alias_entry), "");
+			gtk_entry_set_text (GTK_ENTRY (qee->print_name_entry), "");
 	}
 	else {
 		gtk_entry_set_text (GTK_ENTRY (qee->name_entry), "");
-		gtk_entry_set_text (GTK_ENTRY (qee->alias_entry), "");
+		gtk_entry_set_text (GTK_ENTRY (qee->print_name_entry), "");
 	}
 	g_signal_handlers_unblock_by_func (G_OBJECT (qee->name_entry),
 					   G_CALLBACK (expr_name_changed_cb), qee);
-	g_signal_handlers_unblock_by_func (G_OBJECT (qee->alias_entry),
+	g_signal_handlers_unblock_by_func (G_OBJECT (qee->print_name_entry),
 					   G_CALLBACK (expr_alias_changed_cb), qee);
 
 
