@@ -870,8 +870,7 @@ list_potential_modif_tables (QueryEnv * env)
 				}
 				if (!found) {
 					ltest = FALSE;
-					if (!DB_FIELD (tlist->data)->
-					    default_val)
+					if (!DB_FIELD (tlist->data)->default_value)
 						ltest2 = FALSE;
 				}
 			}
@@ -879,9 +878,7 @@ list_potential_modif_tables (QueryEnv * env)
 		}
 
 		mt->level = ltest ? mt->level | ALL_FIELDS : mt->level;
-		mt->level =
-			ltest2 ? mt->level | ALL_FIELDS_WITH_DEFAULT : mt->
-			level;
+		mt->level = ltest2 ? mt->level | ALL_FIELDS_WITH_DEFAULT : mt->level;
 
 		views = g_slist_next (views);
 	}
@@ -897,8 +894,7 @@ list_potential_modif_tables (QueryEnv * env)
 			mt->nbstars = 3;
 		if (!mt->nbstars && (mt->level == (int) KEY_PRESENT))
 			mt->nbstars = 2;
-		if (!mt->nbstars
-		    && (mt->level >= (int) ALL_FIELDS_WITH_DEFAULT))
+		if (!mt->nbstars && (mt->level >= (int) ALL_FIELDS_WITH_DEFAULT))
 			mt->nbstars = 1;
 
 		views = g_slist_next (views);
