@@ -48,6 +48,8 @@ static void        q_replace_comp    (QueryField *qf, gint ref, GObject   *old,
 /* Weak ref from the refering object */
 static void        q_obj_destroyed_cb (QueryField *qf, GObject *obj);
 
+static void query_field_field_set_field (QueryField *qf, QueryView *qv, DbField *field);
+
 typedef struct {
 	/* The view and field attributs should either be both NULL or both non NULL */
 	QueryView   *view;
@@ -61,6 +63,7 @@ typedef struct {
 
 #define QF_PRIVATE_DATA(qf) ((private_data *) qf->private_data)
 
+
 QueryFieldIface * 
 query_field_field_get_iface()
 {
@@ -554,13 +557,59 @@ q_replace_comp (QueryField *qf, gint ref, GObject   *old, GObject   *new)
 }
 
 
+
+
 /* 
  * 
- * QueryField object's different implementations
+ * Real QueryField object's different methods
  * 
  *
  */
 
+
+QueryField *
+query_field_field_dbfield_new (Query *q, gchar * name, QueryView *qv, DbField *field)
+{
+	QueryField *qf;
+	QueryView *realqv;
+
+	g_return_val_if_fail (q && IS_QUERY (q), NULL);
+	g_return_val_if_fail (field && IS_DB_FIELD (field), NULL);
+	if (qv) {
+		g_return_val_if_fail (IS_QUERY_VIEW (qv) && (qv->query == q), NULL);
+		realqv = qv;
+	}
+	else { 
+		/* try to find a suitable QV... */
+		QueryView *qv2 = NULL;
+		GSList *list;
+		DbTable *table;
+
+		table = database_find_table_from_field (q->conf->db, field);
+
+		list = q->views;
+		while (list && !qv2) {
+			if (IS_DB_TABLE (QUERY_VIEW (list->data)->obj) &&
+			    (DB_TABLE (QUERY_VIEW (list->data)->obj) == table))
+				qv2 = QUERY_VIEW (list->data);
+			list = g_slist_next (list);
+		}
+
+		/* ...and otherwise make one */
+		if (!qv2)
+			realqv = QUERY_VIEW (query_add_view_with_obj (q, G_OBJECT (table)));
+		else
+			realqv = qv2;
+	}
+
+	qf = QUERY_FIELD (query_field_new (q, name, QUERY_FIELD_FIELD));
+	query_field_field_set_field (qf, realqv, field);
+	query_field_activate (qf);
+
+	return qf;
+}
+
+
 ServerDataType  *
 query_field_field_get_data_type (QueryField *qf)
 {
@@ -578,7 +627,7 @@ query_field_field_get_data_type (QueryField *qf)
 	}
 }
 
-void
+static void
 query_field_field_set_field (QueryField *qf, QueryView *qv, DbField *field)
 {
 	gboolean done = FALSE;
