@@ -38,9 +38,8 @@ static GObject   *query_new_id (const gchar * name, Query *parent_query, ConfMan
 
 static gchar *get_from_part_of_sql (Query * q);
 
-static void query_list_joins (Query *q);
-
 #ifdef debug
+static void query_list_joins (Query *q);
 static void query_print_joins (Query *q);
 #endif
 
@@ -68,13 +67,15 @@ enum
 	ENV_DROPPED,
 	QUERY_VIEW_ADDED,
 	QUERY_VIEW_REMOVED,
+	CHILD_QUERY_CREATED,
+	CHILD_QUERY_DROPPED,
 	QUERY_CREATED,
 	QUERY_DROPPED,
 	LAST_SIGNAL
 };
 
 static gint query_signals[LAST_SIGNAL] =
-	{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
+	{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
 
 guint
@@ -263,6 +264,24 @@ query_class_init (QueryClass * class)
 			      marshal_VOID__POINTER, G_TYPE_NONE, 1,
 			      G_TYPE_POINTER);
 	
+	query_signals[CHILD_QUERY_CREATED] =
+		g_signal_new ("child_query_created",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (QueryClass, child_query_created),
+			      NULL, NULL,
+			      marshal_VOID__POINTER, G_TYPE_NONE, 1,
+			      G_TYPE_POINTER);
+	
+	query_signals[CHILD_QUERY_DROPPED] =
+		g_signal_new ("child_query_dropped",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (QueryClass, child_query_dropped),
+			      NULL, NULL,
+			      marshal_VOID__POINTER, G_TYPE_NONE, 1,
+			      G_TYPE_POINTER);
+
 	query_signals[QUERY_CREATED] =
 		g_signal_new ("query_created",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -281,6 +300,7 @@ query_class_init (QueryClass * class)
 			      marshal_VOID__POINTER, G_TYPE_NONE, 1,
 			      G_TYPE_POINTER);
 
+
 	class->field_created =
 		(void (*)(Query * q, QueryField * field)) m_changed;
 	class->field_dropped =
@@ -308,6 +328,9 @@ query_class_init (QueryClass * class)
 	class->query_view_added = NULL;
 	class->query_view_removed = NULL;
 
+	class->child_query_created = NULL;
+	class->child_query_dropped = NULL;
+
 	class->query_created = NULL;
 	class->query_dropped = NULL;
 
@@ -719,7 +742,9 @@ query_dispose (GObject   * object)
 	while (q->joins) {
 		GSList *sub_list;
 		sub_list = (GSList *) q->joins->data;
+#ifdef debug
 		g_print ("Del join %p for query %d\n", sub_list->data, q->id);
+#endif
 		query_del_join (q, QUERY_JOIN (sub_list->data));
 	}
 
@@ -1218,7 +1243,9 @@ real_query_build_from_xml_tree (ConfManager * conf, xmlNodePtr node, Query *pare
 		/* Joins */
 		if (!strcmp (tree->name, "QueryJoinList")) {
 			query_join_list_load_from_xml (q, conf, tree);
+#ifdef debug
 			g_print("\n%s\n", get_from_part_of_sql(q)); /* DEBUG FER */
+#endif
 		}
 
 		/* Where condition */
@@ -1255,7 +1282,9 @@ query_join_list_load_from_xml   (Query *q, ConfManager *conf, xmlNodePtr node)
 			QueryJoin *qj;
 			qj = QUERY_JOIN (query_join_new_from_xml (conf, jnode));
 			real_query_add_join(q, qj);
+#ifdef debug
 			g_print("Query join %p added\n", QUERY_JOIN (qj));
+#endif
 		}
 		jnode = jnode->next;
 	}
@@ -1796,8 +1825,19 @@ query_add_sub_query (Query *q, Query *sibling, Query *sub_query)
 	q->sub_queries = g_slist_insert (q->sub_queries, sub_query, pos);
 	sub_query->parent = q;
 
-	g_print ("sub query %s added to query %s at pos %d\n", sub_query->name, q->name, pos);
-	
+#ifdef debug
+	g_print ("sub query %s (%p) added to query %s at pos %d\n", sub_query->name, sub_query, q->name, pos);
+#endif	
+
+#ifdef debug_signal
+	g_print (">> 'CHILD_QUERY_CREATED' from query_add_sub_query (Query=%s)\n", q->name);
+#endif
+	g_signal_emit (G_OBJECT (q), query_signals[CHILD_QUERY_CREATED], 0, sub_query);
+#ifdef debug_signal
+	g_print ("<< 'CHILD_QUERY_CREATED' from query_add_sub_query (Query=%s)\n", q->name);
+#endif	
+
+
 #ifdef debug_signal
 	g_print (">> 'QUERY_CREATED' from query_add_sub_query (Query=%s)\n", q->name);
 #endif
@@ -1808,9 +1848,9 @@ query_add_sub_query (Query *q, Query *sibling, Query *sub_query)
 
 	/* to have a propagation of the signal */
 	g_signal_connect (G_OBJECT (sub_query), "query_created",
-			    G_CALLBACK (sub_query_created), q);
+			  G_CALLBACK (sub_query_created), q);
 	g_signal_connect (G_OBJECT (sub_query), "query_dropped",
-			    G_CALLBACK (sub_query_dropped), q);
+			  G_CALLBACK (sub_query_dropped), q);
 }
 
 /* test for incompatibilities between the queries
@@ -1926,6 +1966,14 @@ query_del_sub_query (Query *q, Query *sub_query)
 						      G_CALLBACK (sub_query_dropped), q);
 		
 		sub_query->parent = NULL;
+#ifdef debug_signal
+		g_print (">> 'CHILD_QUERY_DROPPED' from query_del_sub_query\n");
+#endif
+		g_signal_emit (G_OBJECT (q), query_signals[CHILD_QUERY_DROPPED], 0, sub_query);
+#ifdef debug_signal
+		g_print ("<< 'CHILD_QUERY_DROPPED' from query_del_sub_query\n");
+#endif	
+
 #ifdef debug_signal
 		g_print (">> 'QUERY_DROPPED' from query_del_sub_query\n");
 #endif
@@ -1956,6 +2004,7 @@ find_views_in_joins_lists (QueryView *vant, QueryView *vsuc, GSList **plists, GS
 
 static GSList *g_slist_set_append (GSList *list, gpointer elem);
 
+#ifdef debug
 /* query_list_joins
  * print the lists of joins list
  * as pointers
@@ -1978,7 +2027,6 @@ query_list_joins (Query *q)
 	}
 }
 
-#ifdef debug
 /* query_print_joins
  *
  * prints the list of joins lists 
@@ -2310,7 +2358,9 @@ query_add_join (Query *q, QueryView *v1, QueryField *f1, QueryView  *v2, QueryFi
 	QueryView *qj_vant = NULL, *qj_vsuc = NULL;
 	GSList *list;
 
+#ifdef debug
 	query_list_joins (q);
+#endif
 
 	/* Look for an existing QueryJoin or define one */
 	list = q->joins;
@@ -2361,7 +2411,9 @@ real_query_add_join (Query * q, QueryJoin *join)
 	g_signal_connect (G_OBJECT (join), "pair_removed",
 			  G_CALLBACK (join_pairs_modified_cb), q);
 
+#ifdef debug
 	query_list_joins (q);
+#endif
 }
 
 
@@ -2377,7 +2429,9 @@ join_destroy_cb (Query *q, QueryJoin *join)
 	if (! q->joins) /* FIXME: here should always be not NULL */
 		return;
 
+#ifdef debug
 	query_list_joins (q);
+#endif
 
 	/* search for the join in q->joins */
 	lists = q->joins;	/* points to a sub-list (lists->data) */
@@ -2446,7 +2500,9 @@ join_destroy_cb (Query *q, QueryJoin *join)
 	g_print ("<< 'JOIN_DROPPED' from query_del_join\n");
 #endif
 
+#ifdef debug
 	query_list_joins (q);
+#endif
 }
 
 static void 
